Skip to contents

Defines and summarizes the column names found in the TADA format for the Criteria and Methodology table for users to fill out.

Usage

TADA_CriteriaDataDictionary(downloads_path = NULL)

Arguments

downloads_path

A character string to define the location of the 'myfileRef.xlsx' file to include the data dictionary to. Default is null to find the path in the Downloads folder path.

Value

An excel data frame tab