Skip to contents

A function to load a Criteria and Methodologies file from the TADACommunityHub as a data frame. The format of these files should match the format of a file generated by TADA_DefineCriteriaMethodology().

Usage

TADA_GetCriteriaFile(org_id = NULL, display_name = NULL)

Arguments

org_id

Character string. The ATTAINS organization identifier. Run TADA_ListCriteriaFiles() for a list of options. Users can enter either the org_id or display_name into this function to retrieve a Criteria and Methods file.

display_name

Character string. The organization display name used for the TADA Module 3 R Shiny App user interface (https://github.com/USEPA/TADAShinyAnalyze). Run TADA_ListCriteriaFiles() for a list of options. Users can enter either the org_id or display_name into this function to retrieve a Criteria and Methods file.

Value

A data frame containing the Criteria and Methodologies File retrieved from the TADACommunityHub based on the user supplied org_id or display_name name.

Examples

loadCriteria_MTDEQ <- TADA_GetCriteriaFile(org_id = "MTDEQ")
loadCriteria_Montana <- TADA_GetCriteriaFile(display_name = "Montana")