Function to update tribal layer shapefiles. Tribal geopackage is stored in inst/extdata. Existing layers with the same name will be deleted first if they exist.
Source:R/TADAGeospatialRefLayers.R
TADA_UpdateTribalLayers.RdFunction to update tribal layer shapefiles. Tribal geopackage is stored in inst/extdata. Existing layers with the same name will be deleted first if they exist.