Skip to contents

addLegendToggle Internal function to apply a button to a TADA leaflet map to toggle the legend on/off.

Usage

addLegendToggle(map = NULL)

Arguments

map

A TADA leaflet map to add the Toggle Legend button.

Value

A TADA map with the Toggle Legend button added