Skip to contents

Get text for tribal marker popup getTribalPopup is used within TADA_addPolys and TADA_addPoints

Usage

getTribalPopup(layer, layername)

Arguments

layer

A map feature layer

layername

Name of the layer

Value

Vector of strings to be used as the text for the popups when clicking on a tribal marker

Examples

if (FALSE) { # \dontrun{
# Read in the Oklahoma Tribal Statistical Areas layer
tribal_gpkg <- "inst/extdata/Tribal.gpkg"
layer <- readLayer(tribal_gpkg, "OKTribe")
# Get popup text for individual markers
getTribalPopup(layer, "Oklahoma Tribal Statistical Areas")
} # }