Skip to contents

Internal function to prepare all ATTAINS geometry from TADA_CreateATTAINSAUMLCrosswalk or TADA_CreateAUMLCrosswalk for display in a leaflet map by running prepATTAINSMapper for all available assessment unit layers.

Usage

prepAllATTAINSMapper(
  lines_layer = NULL,
  polygons_layer = NULL,
  points_layer = NULL,
  catchment_layer = NULL,
  color_ref = NULL,
  auid_list = NULL
)

Arguments

lines_layer

Optional data frame argument. Contains the data required to map ATTAINS assessment unit line geometry. When lines_layer = NULL, no line assessment units are prepared for mapping. Default = NULL.

polygons_layer

Optional data frame argument. Contains the data required to map ATTAINS assessment unit polygon geometry. When polygons_layer = NULL, no polygon assessment units are prepared for mapping. Default = NULL.

points_layer

Optional data frame argument. Contains the data required to map ATTAINS assessment unit point geometry. When points_layer = NULL, no point assessment units are prepared for mapping. Default = NULL.

catchment_layer

Optional data frame argument. Contains the data required to map ATTAINS catchment polygon geometry. When catchment_layer = NULL, no ATTAINS catchments are prepared for mapping. Default = NULL.

color_ref

Optional data frame argument. Contains the columns "overall status" (ATTAINS overall status), "col" (light fill color), "dark_col" (darker color for points or outlines), and "priority" (for displaying on map). When color_ref = NULL, the function getATTAINSColorRef is used to set the standardized colors used for ATTAINS assessment units throughout EPATADA. The default is color_ref = NULL.

auid_list

A list of any ATTAINS assessment unit identifiers that should be excluded from the output (not included in map).

Value

A list of data frames ready for use in a TADA leaflet map.