List Criteria and Methodologies Files Available in the TADACommunityHub
Source:R/TADACommunityHub.R
TADA_ListCriteriaFiles.RdRetrieves the complete listing of Criteria and Methodologies files from the TADACommunityHub repository. The ATTAINS.OrganizationIdentifier or display_name returned can be used as function inputs in the TADA_GetCriteriaFile() function to retrieve a Criteria and Methodologies File.