Add points from a spatial layer to a leaflet map
Examples
if (FALSE) { # \dontrun{
# Create a leaflet map
lmap <- leaflet::leaflet() |>
leaflet::addProviderTiles("Esri.WorldTopoMap", group = "World topo") |>
leaflet::addMapPane("featurelayers", zIndex = 300)
# Add the Virginia Federally Recognized Tribes feature layer to the map
tribal_gpkg <- "inst/extdata/Tribal.gpkg"
lmap <- TADA_addPoints(lmap, tribal_gpkg,"VATribe",
"Tribes", "Virginia Federally Recognized Tribes")
lmap
} # }