Add polygons from a spatial layer to a leaflet map
Examples
if (FALSE) { # \dontrun{
# Create a leaflet map
lmap <- leaflet::leaflet() |>
leaflet::addProviderTiles("Esri.WorldTopoMap", group = "World topo") |>
leaflet::addMapPane("featurelayers", zIndex = 300)
# Add the American Indian Reservations feature layer to the map
tribal_gpkg <- "inst/extdata/Tribal.gpkg"
lmap <- TADA_addPolys(lmap, tribal_gpkg,"AmericanIndian",
"Tribes", "American Indian Reservations")
lmap
} # }