addLayerControl Internal function to add layer control to a TADA leaflet map to toggle the legend on/off.
Source:R/GeospatialUtilities.R
addLayerControl.RdaddLayerControl Internal function to add layer control to a TADA leaflet map to toggle the legend on/off.