addLegendToggle Internal function to apply a button to a TADA leaflet map to toggle the legend on/off.
Source:R/GeospatialUtilities.R
addLegendToggle.RdaddLegendToggle Internal function to apply a button to a TADA leaflet map to toggle the legend on/off.