Internal function to add a reset button to the map to return it to its
original extent.
Usage
addMapReset(map, bbox = NULL)
Arguments
- map
A leaflet map to add the reset button to.
- bbox
The bounding box the map view should return to.
Value
The original map with a reset button added.